pub struct Env { /* private fields */ }Implementations
Sourceimpl Env
impl Env
Sourcepub fn split(&mut self) -> (QueryRunner, UpdateRunner)
pub fn split(&mut self) -> (QueryRunner, UpdateRunner)
Split the environment to the two query runner object and the update runner to run queries and updates.